#include "automaton.hpp"
#include "temps.h"


Automaton::Automaton()
{
//build the different modules of all modules
  hqi=new HQI();	
  blue=new Blue();
  pump=new Pump();
  temperature=new Temperature();
  skimmer=new Skimmer();
  peristatic=new Peristatic();
  rah=new Rah();
  osmolation=new Osmolation();
  ventilator=new Ventilator();
  init();
}

Automaton::~Automaton()
{
//delete all modules
  delete hqi;
  delete blue;
  delete skimmer;
  delete temperature;
  delete pump;
  delete peristatic;
  delete rah;
  delete osmolation;
  delete ventilator;
}

void Automaton::init()
{
  getstart=0;
  
//initialize all modules
  hqi->init();
  blue->init();
  skimmer->init();
  temperature->init();
  pump->init();
  peristatic->init();
  rah->init();
  osmolation->init();
  ventilator->init();
}

void Automaton::restart (connexion & c)
{
  int n;
  
//restart the automaton without saving BD
  if (getstart==1)
    {
      // normal restart
      cout << "restarting automaton" << endl;
      c.insert_log("automaton restarted");
      n=fork();
      if (n==0) {execl("./automate","automate",NULL);}
      
    }
  
//restart the automaton with reinit of BD
  if (getstart==2)
    {
      cout << "restarting automaton with fresh bd" << endl;
      c.insert_log("automaton restarted with reinit of bd");
      n=fork();
      if (n==0) {execl("./automate","automate","init-bd",NULL);}
    }
  
//stop the automaton
  if (getstart==3)
    {
      cout << "stopping automaton" << endl;
      c.insert_log("automaton stopped");
    }
}

void Automaton::getInputState(K8055 &k,config &cfg)
{
//getting input states
  pump->setStop(k.read(cfg.STOP_PUMP));
  skimmer->setStop(k.read(cfg.STOP_SKIMMER));
  osmolation->setIni(k.read(cfg.OSMOLATION));
  osmolation->setEmpty_reserv(k.read(cfg.RESERV));
  osmolation->setCaptor_high(k.read(cfg.HIGH));
}
