/*
  Name : configuration.cpp
  Copyright : KPAMEGAN & ROUSSET
  Authors : KPAMEGAN Karel, ROUSSET Baptiste
  Description: file which contents functions to display acquisitions on a LCD screen
*/

#include "configuration.hpp"
#include <string.h>
#include <iostream>

/*****************************************FUNCTIONS*******************************************/

void nano(int speed);

/*****************************************METHODS**********************************************/

/*
  Name : Configuration
  Finality : this is a constructor
  Decription : set separators on the screen,
               set names of parameters
*/
Configuration::Configuration(char *name1,char *name2,char *name3,char *name4)
{
  set_separators();
  set_param1(name1);
  set_param2(name2);
  set_param3(name3);
  set_param4(name4);
  set_param1_value("off");
  set_param2_value("off");
  set_param3_value("off");
  set_param4_value("off");
}

/*
  Name : Configuration
  Finality : this is a constructor
  Decription : set separators on the screen,
               set default value to the lines of the screen
*/
Configuration::Configuration(int i)
{
  set_separators();
  if ( i==1)
    {
      set_param1("Temp C");
      set_param2("Ecumeur");
      set_param3("Ppes dos.");
      set_param4("Chauffage");
   }
  if ( i==2)
    {
      set_param1("Res d'eau");
      set_param2("Osmolat.");
      set_param3("R.A.H.   ");
      set_param4("Gpe ppes ");
   }

  set_param1_value("off");
  set_param2_value("off");
  set_param3_value("off");
  set_param4_value("off");
}

/*
  Name : ~Configuration
  Finality : this is the destructor
  Decription : empty ( call the "Screen" destructor )
*/
Configuration::~Configuration()
{

}

/*
  Name : set_param1
  Finality : set the name of a pamater on the screen
  Decription : set the name of the first pamater on the top left of the screen
*/
void Configuration::set_param1(char *name)
{
  int i,s=strlen(name);
  if ( s > 9 )
   printf("name1 too long\n"),exit(0);
  for(i=0;i<s;i++)
    line0[i]=name[i];
}

/*
  Name : set_param2
  Finality : set the name of a pamater on the screen
  Decription : set the name of the second pamater on the bottom left of the screen
*/
void Configuration::set_param2(char *name)
{
  int i,s=strlen(name);
  if ( s > 9 )
   printf("name2 too long\n"),exit(0);
  for(i=0;i<s;i++)
    line2[i]=name[i];
}

/*
  Name : set_param3
  Finality : set the name of a pamater on the screen
  Decription : set the name of the third pamater on the top right of the screen
*/
void Configuration::set_param3(char *name)
{
  int i,s=strlen(name);
  if ( s > 9 )
   printf("name3 too long\n"),exit(0);
  for(i=0;i<s;i++)
    line0[11+i]=name[i];
}

/*
  Name : set_param4
  Finality : set the name of a pamater on the screen
  Decription : set the name of the last pamater on the bottom right of the screen
*/
void Configuration::set_param4(char *name)
{
  int i,s=strlen(name);
  if ( s > 9 )
   printf("name4 too long\n"),exit(0);
  for(i=0;i<s;i++)
    line2[11+i]=name[i];
}

/*
  Name : set_param1_value
  Finality : set the value of a pamater on the screen
  Decription : set the value of the first pamater on the top left of the screen
*/
void Configuration::set_param1_value(char *val)
{
  int j=0,i,s=strlen(val);
  param1=val;
  if ( s > 9 )
   printf("param1 too long\n"),exit(0);
  else clean_param_value(1);
  for(i=9-s;val[j]!='\0';i++)
    {
      line1[i]=val[j];
      j++;
    }
}

/*
  Name : set_param2_value
  Finality : set the value of a pamater on the screen
  Decription : set the value of the second pamater on the bottom left of the screen
*/
void Configuration::set_param2_value(char *val)
{
  int j=0,i,s=strlen(val);
  param2=val;
  if ( s > 9 )
   printf("param2 too long\n"),exit(0);
  else clean_param_value(2);
  for(i=9-s;val[j]!='\0';i++)
    {
      line3[i]=val[j];
      j++;
    }
}

/*
  Name : set_param3_value
  Finality : set the value of a pamater on the screen
  Decription : set the value of the third pamater on the top right of the screen
*/
void Configuration::set_param3_value(char *val)
{
  int j=0,i,s=strlen(val);
  param3=val;
  if ( s > 9 )
   printf("param3 too long\n"),exit(0);
  else clean_param_value(3);
  for(i=20-s;val[j]!='\0';i++)
    {
      line1[i]=val[j];
      j++;
    }
}

/*
  Name : set_param4_value
  Finality : set the value of a pamater on the screen
  Decription : set the of value the last pamater on the bottom right of the screen
*/
void Configuration::set_param4_value(char *val)
{
  int j=0,i,s=strlen(val);
  param4=val;
  if ( s > 9 )
   printf("param4 too long\n"),exit(0);
  else clean_param_value(4);
  for(i=20-s;val[j]!='\0';i++)
    {
      line3[i]=val[j];
      j++;
    }
}

/*
  Name : clean_param_value
  Finality : delete the value of a param
  Decription : delete the value of the param which is given in argument
*/
void Configuration::clean_param_value(int nop)
{
  int i=0;
  switch ( nop )
    {
    case 1 : for(i=0;i<9;i++)
	line1[i]=' ';break;
    case 2 : for(i=0;i<9;i++)
	line3[i]=' ';break;
    case 3 : for(i=11;i<19;i++)
	line1[i]=' ';break;
    case 4 : for(i=11;i<19;i++)
	line3[i]=' ';break;
    }
}

/*
  Name : clean_param_name
  Finality : delete the name of a param
  Decription : delete the name of the param which is given in argument
*/
void Configuration::clean_param_name(int nop)
{
  int i=0;
  switch ( nop )
    {
    case 1 : for(i=0;i<9;i++)
	line0[i]=' ';break;
    case 2 : for(i=0;i<9;i++)
	line2[i]=' ';break;
    case 3 : for(i=11;i<19;i++)
	line0[i]=' ';break;
    case 4 : for(i=11;i<19;i++)
	line2[i]=' ';break;
    }
}



